@@ -4,13 +4,15 @@
 #' @importFrom R6 R6Class
 #' @export
 #' @keywords ISO data quality result
-#' @return Object of \code{\link{R6Class}} for modelling an ISO Result
-#' @format \code{\link{R6Class}} object.
+#' @return Object of \code{\link[R6]{R6Class}} for modelling an ISO Result
+#' @format \code{\link[R6]{R6Class}} object.
 #'  
 #' @note abstract class
 #'  
 #' @references 
-#'   ISO 19115:2003 - Geographic information -- Metadata 
+#'   - ISO 19139 \url{https://schemas.isotc211.org/19139/-/gmd/1.0/gmd/#element_AbstractDQ_Result}
+#' 
+#'   - ISO 19115-3 \url{https://schemas.isotc211.org/19157/-/mdq/1.2/mdq/#element_AbstractDQ_Result}
 #' 
 #' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
 #'
@@ -18,20 +20,17 @@ ISOAbstractResult <- R6Class("ISOAbstractResult",
   inherit = ISOAbstractObject,
   private = list(
     xmlElement = "AbstractDQ_Result",
-    xmlNamespacePrefix = "GMD"
+    xmlNamespacePrefix = list(
+      "19139" = "GMD",
+      "19115-3" = "MDQ"
+    )
   ),
   public = list(
-    #'@field specification specification
-    specification = NULL,
-    #'@field explanation explanation
-    explanation = NULL,
-    #'@field pass pass
-    pass = NULL,
     
     #'@description Initializes object
-    #'@param xml object of class \link{XMLInternalNode-class}
+    #'@param xml object of class \link[XML]{XMLInternalNode-class}
     initialize = function(xml = NULL){
       super$initialize(xml = xml)
     }
   )                        
-)
\ No newline at end of file
+)
