@@ -4,8 +4,8 @@
 #' @importFrom R6 R6Class
 #' @export
 #' @keywords ISO dimension
-#' @return Object of \code{\link{R6Class}} for modelling an ISO Dimension
-#' @format \code{\link{R6Class}} object.
+#' @return Object of \code{\link[R6]{R6Class}} for modelling an ISO Dimension
+#' @format \code{\link[R6]{R6Class}} object.
 #' 
 #' @examples
 #'    #create dimension
@@ -16,7 +16,9 @@
 #'    xml <- md$encode()
 #'    
 #' @references 
-#'   ISO 19115:2003 - Geographic information -- Metadata 
+#'   - ISO 19139 \url{https://schemas.isotc211.org/19139/-/gmd/1.0/gmd/#element_MD_Dimension}
+#'   
+#'   - ISO 19115-3 \url{https://schemas.isotc211.org/19115/-3/msr/1.0/msr/#element_MD_Dimension}
 #' 
 #' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
 #'
@@ -24,7 +26,10 @@ ISODimension <- R6Class("ISODimension",
    inherit = ISOAbstractObject,
    private = list(
      xmlElement = "MD_Dimension",
-     xmlNamespacePrefix = "GMD"
+     xmlNamespacePrefix = list(
+       "19139" = "GMD",
+       "19115-3" = "MSR"
+     )
    ),
    public = list(
      #'@field dimensionName dimensionName [1..1]: ISODimensionNameType
@@ -35,7 +40,7 @@ ISODimension <- R6Class("ISODimension",
      resolution = NULL,
      
      #'@description Initializes object
-     #'@param xml object of class \link{XMLInternalNode-class}
+     #'@param xml object of class \link[XML]{XMLInternalNode-class}
      initialize = function(xml = NULL){
        super$initialize(xml = xml)
      },
@@ -71,4 +76,4 @@ ISODimension <- R6Class("ISODimension",
      }
      
    )                        
-)
\ No newline at end of file
+)
