@@ -4,8 +4,8 @@
 #' @importFrom R6 R6Class
 #' @export
 #' @keywords ISO geographic description
-#' @return Object of \code{\link{R6Class}} for modelling an ISO GeographicDescription
-#' @format \code{\link{R6Class}} object.
+#' @return Object of \code{\link[R6]{R6Class}} for modelling an ISO GeographicDescription
+#' @format \code{\link[R6]{R6Class}} object.
 #' 
 #' @examples 
 #'   md <- ISOGeographicDescription$new()
@@ -13,7 +13,9 @@
 #'   xml <- md$encode()
 #' 
 #' @references 
-#'   ISO 19115:2003 - Geographic information -- Metadata
+#'  - ISO 19139 \url{https://schemas.isotc211.org/19139/-/gmd/1.0/gmd/#element_EX_GeographicDescription}
+#'  
+#'  - ISO 19115-3 \url{https://schemas.isotc211.org/19115/-3/gex/1.0/gex/#element_EX_GeographicDescription}
 #' 
 #' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
 #'
@@ -21,14 +23,17 @@ ISOGeographicDescription <- R6Class("ISOGeographicDescription",
   inherit = ISOGeographicExtent,
   private = list(
     xmlElement = "EX_GeographicDescription",
-    xmlNamespacePrefix = "GMD"
+    xmlNamespacePrefix = list(
+      "19139" = "GMD",
+      "19115-3" = "GEX"
+    )
   ),
   public = list(
     #'@field geographicIdentifier geographicIdentifier [1..1]: character
     geographicIdentifier = NULL,
     
     #'@description Initializes object
-    #'@param xml object of class \link{XMLInternalNode-class}
+    #'@param xml object of class \link[XML]{XMLInternalNode-class}
     initialize = function(xml = NULL){
       super$initialize(xml = xml)
     },
@@ -43,4 +48,4 @@ ISOGeographicDescription <- R6Class("ISOGeographicDescription",
     }
     
   )                                          
-)
\ No newline at end of file
+)
