@@ -5,8 +5,8 @@
 #' @import XML
 #' @export
 #' @keywords ISO imagery metadata element
-#' @return Object of \code{\link{R6Class}} for modelling an ISO Imagery Metadata
-#' @format \code{\link{R6Class}} object.
+#' @return Object of \code{\link[R6]{R6Class}} for modelling an ISO Imagery Metadata
+#' @format \code{\link[R6]{R6Class}} object.
 #' 
 #' @examples
 #'     #example 1 - WRITE: Create an ISO metadata and encode it as XML
@@ -216,7 +216,7 @@
 #'    
 #'    #create dataQuality object with a 'dataset' scope
 #'    dq <- ISODataQuality$new()
-#'    scope <- ISOScope$new()
+#'    scope <- ISODataQualityScope$new()
 #'    scope$setLevel("dataset")
 #'    dq$setScope(scope)
 #'   
@@ -323,7 +323,9 @@
 #'    }
 #' 
 #' @references 
-#'   ISO 19115-2:2009 - Geographic information -- Metadata -- Part 2: Extensions for imagery and gridded data
+#'   - 19139 \url{https://schemas.isotc211.org/19115/-2/gmi/1.0/gmi/#element_MI_Metadata}
+#'   
+#'   - 19115-3 \url{https://schemas.isotc211.org/19115/-3/mac/2.0/mac/#element_MI_Metadata}
 #' 
 #' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
 #'
@@ -332,7 +334,10 @@ ISOImageryMetadata <- R6Class("ISOImageryMetadata",
   private = list(
     document = TRUE,
     xmlElement = "MI_Metadata",
-    xmlNamespacePrefix = "GMI"
+    xmlNamespacePrefix = list(
+      "19139" = "GMI",
+      "19115-3" =  "MAC"
+    )
   ),
   public = list(
     
@@ -340,7 +345,7 @@ ISOImageryMetadata <- R6Class("ISOImageryMetadata",
      acquisitionInformation = list(),
     
      #'@description Initializes object
-     #'@param xml object of class \link{XMLInternalNode-class}
+     #'@param xml object of class \link[XML]{XMLInternalNode-class}
      initialize = function(xml = NULL){
        super$initialize(xml = xml)
      },
