@@ -4,8 +4,8 @@
 #' @importFrom R6 R6Class
 #' @export
 #' @keywords ISO imagery nominal resolution
-#' @return Object of \code{\link{R6Class}} for modelling an ISO imagery nominal resolution
-#' @format \code{\link{R6Class}} object.
+#' @return Object of \code{\link[R6]{R6Class}} for modelling an ISO imagery nominal resolution
+#' @format \code{\link[R6]{R6Class}} object.
 #' 
 #' @examples
 #'   #encoding
@@ -18,7 +18,9 @@
 #'   xml <- dq$encode()
 #' 
 #' @references 
-#'   ISO 19115-2:2009 - Geographic information -- Metadata Part 2: Extensions for imagery and gridded data
+#'   - ISO 19139 \url{https://schemas.isotc211.org/19115/-2/gmi/1.0/gmi/#element_LE_NominalResolution}
+#'   
+#'   - ISO 19115-3 \url{https://schemas.isotc211.org/19115/-3/mrl/2.0/mrl/#element_LE_NominalResolution}
 #' 
 #' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
 #' 
@@ -26,7 +28,10 @@ ISOImageryNominalResolution <- R6Class("ISOImageryNominalResolution",
    inherit = ISODataQualityAbstractElement,
    private = list(
      xmlElement = "LE_NominalResolution",
-     xmlNamespacePrefix = "GMI"
+     xmlNamespacePrefix = list(
+       "19139" = "GMI",
+       "19115-3" = "MRL"
+     )
    ),
    public = list(
      #'@field scanningResolution scanningResolution [0..1]: ISODistance
@@ -35,7 +40,7 @@ ISOImageryNominalResolution <- R6Class("ISOImageryNominalResolution",
      groundResolution = NULL,
      
      #'@description Initializes object
-     #'@param xml object of class \link{XMLInternalNode-class}
+     #'@param xml object of class \link[XML]{XMLInternalNode-class}
      initialize = function(xml = NULL){
        super$initialize(xml = xml)
      },
@@ -60,4 +65,4 @@ ISOImageryNominalResolution <- R6Class("ISOImageryNominalResolution",
        self$scanningResolution <- NULL
      }
    )                        
-)
\ No newline at end of file
+)
