@@ -4,8 +4,8 @@
 #' @importFrom R6 R6Class
 #' @export
 #' @keywords ISO extent
-#' @return Object of \code{\link{R6Class}} for modelling an ISO Resolution
-#' @format \code{\link{R6Class}} object.
+#' @return Object of \code{\link[R6]{R6Class}} for modelling an ISO Resolution
+#' @format \code{\link[R6]{R6Class}} object.
 #' 
 #' @examples 
 #'   md <- ISOResolution$new()
@@ -13,7 +13,9 @@
 #'   xml <- md$encode()
 #' 
 #' @references 
-#'   ISO 19115:2003 - Geographic information -- Metadata
+#'   - ISO 19139 \url{https://schemas.isotc211.org/19139/-/gmd/1.0/gmd/#element_MD_Resolution}
+#'   
+#'   - ISO 19115-3 \url{https://schemas.isotc211.org/19115/-3/mri/1.0/mri/#element_MD_Resolution}
 #' 
 #' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
 #'
@@ -21,7 +23,10 @@ ISOResolution <- R6Class("ISOResolution",
    inherit = ISOAbstractObject,
    private = list(
      xmlElement = "MD_Resolution",
-     xmlNamespacePrefix = "GMD"
+     xmlNamespacePrefix = list(
+       "19139" = "GMD",
+       "19115-3" = "MRI"
+     )
    ),
    public = list(
      #Choice [1..1]
@@ -31,7 +36,7 @@ ISOResolution <- R6Class("ISOResolution",
      distance = NULL,
      
      #'@description Initializes object
-     #'@param xml object of class \link{XMLInternalNode-class}
+     #'@param xml object of class \link[XML]{XMLInternalNode-class}
      #'@param defaults list of defaults
      initialize = function(xml = NULL, defaults = list()){        
        super$initialize(xml, defaults = defaults)
@@ -63,4 +68,4 @@ ISOResolution <- R6Class("ISOResolution",
        self$equivalentScale = NULL
      }
    )
-)
\ No newline at end of file
+)
